Learn R Programming

presmTP (version 1.1.0)

summary.pstp: Summarizing fits of "pstp" class

Description

Returns a a data.frame or list containing the estimates of the probabilities.

Usage

# S3 method for pstp
summary(object, state_ini = 0, times = NULL, ...)

Arguments

object

A fitted pstp object as produced by presmTP.

state_ini

Initial state of the transition. Defaults to state_ini=0.

times

Vector of times; the returned data frame will contain 1 row for each time.

...

For future methods.

Value

A data frame or a list containing the estimates of the probability.

Examples

Run this code
# NOT RUN {
res<- presmTP(data = colonIDM, s = 365, method = "uns")
summary(res, state_ini=1, times=365*1:5)
# }

Run the code above in your browser using DataLab