powered by
Returns a a data.frame or list containing the estimates of the probabilities.
# S3 method for pstp summary(object, state_ini = 0, times = NULL, ...)
A fitted pstp object as produced by presmTP.
Initial state of the transition. Defaults to state_ini=0.
Vector of times; the returned data frame will contain 1 row for each time.
For future methods.
A data frame or a list containing the estimates of the probability.
# NOT RUN { res<- presmTP(data = colonIDM, s = 365, method = "uns") summary(res, state_ini=1, times=365*1:5) # }
Run the code above in your browser using DataLab